@@ -7,9 +7,11 @@ from yalafi.defs import InitModule
 
 require_packages = []
 
-def init_module(parser, options):
+def init_module(parser, options, position):
     parms = parser.parms
 
+    parser.global_latex_options += options
+
     macros_latex = r"""
 
         \newcommand{\KOMAoption}[1]{}
