@@ -21,7 +21,7 @@ from . import utils
 
 #   macros \newcommand, \renewcommand
 #
-def h_newcommand(parser, buf, mac, args, pos):
+def h_newcommand(parser, buf, mac, args, delim, pos):
     name = parser.get_text_direct(args[1])
     if name in parser.parms.newcommand_ignore:
         return []
@@ -52,7 +52,7 @@ def h_newcommand(parser, buf, mac, args, pos):
 #   --> now only used by h_newtheorem()
 #
 def h_theorem(name):
-    def handler (parser, buf, mac, args, pos):
+    def handler (parser, buf, mac, args, delim, pos):
         out = [defs.TextToken(pos, name, pos_fix=True)]
         if args[0]:
             # there is a [.] option
@@ -73,19 +73,19 @@ def h_theorem(name):
 
 #   \newtheorem
 #
-def h_newtheorem(parser, buf, mac, args, pos):
+def h_newtheorem(parser, buf, mac, args, delim, pos):
     name = parser.get_text_expanded(args[0])
     title = parser.get_text_expanded(args[2])
-    def f(parser, options):
+    def f(parser, options, position):
         parms = parser.parms
         envs = [defs.Environ(parms, name, args='O', repl=h_theorem(title))]
         return defs.InitModule(environments=envs)
-    parser.modify_parameters(f, [])
+    parser.modify_parameters(f, [], pos)
     return []
 
 #   heading macros: append '.', unless last char in parms.heading_punct
 #
-def h_heading(parser, buf, mac, args, pos):
+def h_heading(parser, buf, mac, args, delim, pos):
     arg = args[2]
     txt = parser.get_text_expanded(arg).strip()
     if (txt and parser.parms.heading_punct
@@ -95,14 +95,14 @@ def h_heading(parser, buf, mac, args, pos):
 
 #   \phantom, \hphantom
 #
-def h_phantom(parser, buf, mac, args, pos):
+def h_phantom(parser, buf, mac, args, delim, pos):
     if len(parser.get_text_expanded(args[0])) > 0:
         return [defs.SpecialToken(pos, '\\;')]
     return []
 
 #   macro \cite[opt]
 #
-def h_cite(parser, buf, mac, args, pos):
+def h_cite(parser, buf, mac, args, delim, pos):
     if args[0]:
         out = [defs.TextToken(pos, '[0,', pos_fix=True),
                     defs.SpaceToken(pos, ' ', pos_fix=True)]
@@ -114,10 +114,11 @@ def h_cite(parser, buf, mac, args, pos):
                     defs.ActionToken(pos)]
     return out
 
-#   macro \LTinclude: read macro definitions from file
+#   macro \LTinput: read macro definitions from file
 #   - this also activates packages and switches languages
+#   - check for recursive inclusion of a file
 #
-def h_load_defs(parser, buf, mac, args, pos):
+def h_load_defs(parser, buf, mac, args, delim, pos):
     if not parser.read_macros:
         return []
     file = parser.get_text_expanded(args[0])
@@ -125,13 +126,17 @@ def h_load_defs(parser, buf, mac, args, pos):
     if not ok:
         return utils.latex_error('could not read file ' + repr(file),
                                         pos, parser.latex, parser.parms)
-    toks = parser.parser_work(latex)
+    try:
+        toks = parser.parser_work(latex)
+    except RecursionError:
+        utils.fatal('Problem while executing "' + mac.name + '{' + file
+                    + '}".\n' + '*** Is the file included recursively?')
     return utils.filter_set_toks(toks, pos, defs.LanguageToken)
 
 #   read definitions for a LaTeX package
 #
 def h_load_module(prefix):
-    def f(parser, buf, mac, args, pos):
+    def f(parser, buf, mac, args, delim, pos):
         options = parser.parse_keyvals_list(args[0])
         options = parser.expand_keyvals(options)
         packs = parser.get_text_expanded(args[1])
@@ -140,7 +145,7 @@ def h_load_module(prefix):
             p = p.strip()
             if p:
                 f = utils.get_module_handler(p, prefix)
-                out += parser.init_package(p, f, options)
+                out += parser.init_package(p, f, options, pos)
         return utils.filter_set_toks(out, pos, None)
     return f
 
