@@ -7,13 +7,14 @@ from yalafi.defs import InitModule, Environ, SpaceToken, TextToken
 
 require_packages = []
 
-def init_module(parser, options):
+def init_module(parser, options, position):
     parms = parser.parms
 
     macros_latex = r"""
 
         \newcommand{\qedhere}{}
         \newcommand{\theoremstyle}[1]{}
+        \newcommand{\newtheoremstyle}[9]{}
 
     """
 
@@ -28,7 +29,7 @@ def init_module(parser, options):
     return InitModule(macros_latex=macros_latex, macros_python=macros_python,
                         environments=environments)
 
-def h_proof(parser, buf, mac, args, pos):
+def h_proof(parser, buf, mac, args, delim, pos):
     if args[0]:
         ret = args[0]
     else:
