@@ -51,6 +51,7 @@ class Parameters:
         \newcommand{\label}[1]{}
         \newcommand{\LaTeX}{LaTeX}
         \newcommand{\newline}{ }
+        \newcommand{\nobreakspace}{~}
         \newcommand{\O}{Ø}
         \newcommand{\o}{ø}
         \newcommand{\OE}{Œ}
@@ -170,26 +171,32 @@ class Parameters:
             proof_name = 'Proof',
             math_repl_inline = ['B-B-B', 'C-C-C', 'D-D-D',
                                         'E-E-E', 'F-F-F', 'G-G-G'],
+            math_repl_inline_vowel = None,
             math_repl_display = ['U-U-U', 'V-V-V', 'W-W-W',
                                         'X-X-X', 'Y-Y-Y', 'Z-Z-Z'],
+            math_repl_display_vowel = None,
             math_op_text = {'+': 'plus', '-': 'minus',
                                     '\\cdot': 'times', '\\times': 'times',
                                     '/': 'over',
                                     None: 'equal'},     # default value
             lang_change_repl = ['K-K-K', 'L-L-L', 'M-M-M', 'N-N-N'],
+            lang_change_repl_vowel = None,
             short_macros = {}
         )
         settings['de'] = ParserLanguageSettings(
             proof_name = 'Beweis',
             math_repl_inline = ['B-B-B', 'C-C-C', 'D-D-D',
                                         'E-E-E', 'F-F-F', 'G-G-G'],
+            math_repl_inline_vowel = None,
             math_repl_display = ['U-U-U', 'V-V-V', 'W-W-W',
                                         'X-X-X', 'Y-Y-Y', 'Z-Z-Z'],
+            math_repl_display_vowel = None,
             math_op_text = {'+': 'plus', '-': 'minus',
                                     '\\cdot': 'mal', '\\times': 'mal',
                                     '/': 'durch',
                                     None: 'gleich'},    # default value
             lang_change_repl = ['K-K-K', 'L-L-L', 'M-M-M', 'N-N-N'],
+            lang_change_repl_vowel = None,
             short_macros = {
                 '"-': '',
                 '"=': '-',
@@ -208,13 +215,16 @@ class Parameters:
             proof_name = 'Доказательство',
             math_repl_inline = ['Б-Б-Б', 'В-В-В', 'Г-Г-Г',
                                         'Д-Д-Д', 'Е-Е-Е', 'Ж-Ж-Ж'],
+            math_repl_inline_vowel = None,
             math_repl_display = ['Ц-Ц-Ц', 'Ч-Ч-Ч', 'Ш-Ш-Ш',
                                         'Ы-Ы-Ы', 'Э-Э-Э', 'Ю-Ю-Ю'],
+            math_repl_display_vowel = None,
             math_op_text = {'+': 'плюс', '-': 'минус',
                                     '\\cdot': 'раз', '\\times': 'раз',
                                     '/': 'на',
                                     None: 'равно'},     # default value
             lang_change_repl = ['К-К-К', 'Л-Л-Л', 'М-М-М', 'Н-Н-Н'],
+            lang_change_repl_vowel = None,
             short_macros = {}
         )
 
@@ -386,7 +396,7 @@ class Parameters:
             '=', '\\eq', '\\ne', '\\neq',
             '<', '>', '\\le', '\\leq', '\\ge', '\\geq',
             ':', ':=', '\\to', '\\cap', '\\cup',
-            '\\Leftrightarrow',
+            '\\Rightarrow', '\\Leftarrow', '\\Leftrightarrow',
             '\\subset', '\\subseteq', '\\supset', '\\supseteq',
             '\\stackrel',
 
@@ -441,6 +451,17 @@ class Parameters:
     def lang_context_lang(self):
         return self.parser_lang_stack[-1][1]
 
+    #   deactivate special macros and magic comments
+    #
+    def no_specials(self):
+        self.comment_skip_begin = 'x'
+        self.comment_skip_end = 'x'
+        self.macro_defs_python += [
+            Macro(self, self.macro_filter_add, args='A', repl=''),
+            Macro(self, self.macro_filter_alter, args='AA', repl='#1'),
+            Macro(self, self.macro_filter_skip, args='A', repl='#1'),
+        ]
+
     def __init__(self, language='en'):
         self.init_collections()
         self.init_math_collections()
@@ -453,13 +474,29 @@ class Parameters:
 
 
 class ParserLanguageSettings:
-    def __init__(self, proof_name, math_repl_inline, math_repl_display,
-                        math_op_text, lang_change_repl, short_macros):
+    def __init__(self, proof_name,
+                        math_repl_inline, math_repl_inline_vowel,
+                        math_repl_display, math_repl_display_vowel,
+                        math_op_text,
+                        lang_change_repl, lang_change_repl_vowel,
+                        short_macros):
         self.proof_name = proof_name
         self.math_repl_inline = math_repl_inline
+        if math_repl_inline_vowel is None:
+            self.math_repl_inline_vowel = math_repl_inline
+        else:
+            self.math_repl_inline_vowel = math_repl_inline_vowel
         self.math_repl_display = math_repl_display
+        if math_repl_display_vowel is None:
+            self.math_repl_display_vowel = math_repl_display
+        else:
+            self.math_repl_display_vowel = math_repl_display_vowel
         self.math_op_text = math_op_text
         self.lang_change_repl = lang_change_repl
+        if lang_change_repl_vowel is None:
+            self.lang_change_repl_vowel = lang_change_repl
+        else:
+            self.lang_change_repl_vowel = lang_change_repl_vowel
         self.short_macros = short_macros
         self.active_chars = set(k[0] for k in self.short_macros.keys())
 
