@@ -29,6 +29,7 @@ class Parser:
         self.parms = parms
         self.read_macros = read_macros
         self.packages = {}
+        self.global_latex_options = []      # from \documentclass
         self.the_macros = {}
         self.the_environments = {}
         self.mathparser = mathparser.MathParser(self)
@@ -45,12 +46,12 @@ class Parser:
         self.item_lab_stack = [(labs_default(0), '')]
 
         # initialise and modify parameters, macros, etc.
-        builtin = [], lambda p, o: defs.InitModule(
+        builtin = [], lambda p, o, n: defs.InitModule(
                                 macros_latex=parms.macro_defs_latex,
                                 macros_python=parms.macro_defs_python,
                                 environments=parms.environment_defs)
         for name, actions in [('', builtin)] + packages:
-            self.init_package(name, actions, [])
+            self.init_package(name, actions, [], 0)
 
     #   call handler of a package module:
     #   - load other required packages
@@ -59,18 +60,20 @@ class Parser:
     #   --> only do all that if package not yet loaded, or if options have
     #       changed
     #
-    def init_package(self, name, actions, options):
+    def init_package(self, name, actions, options, position):
         out = []
-        if name and name in self.packages and self.packages[name] == options:
+        if (name and name in self.packages and
+                self.packages[name] == self.global_latex_options + options):
             return out
         try:
             for requ in actions[0]:
                 if requ not in self.packages or self.packages[requ] == options:
                     out += self.init_package(requ, utils.get_module_handler(
-                                    requ, self.parms.package_modules), options)
+                                        requ, self.parms.package_modules),
+                                        options, position)
             if name:
-                self.packages[name] = options
-            out += self.modify_parameters(actions[1], options)
+                self.packages[name] = self.global_latex_options + options
+            out += self.modify_parameters(actions[1], options, position)
         except:
             utils.fatal('error loading module ' + repr(name))
         return out
@@ -79,8 +82,8 @@ class Parser:
     #   - used by package extension mechanism
     #   - used by handlers of LaTeX macros / environments
     #
-    def modify_parameters(self, f, options):
-        mods = f(self, options)
+    def modify_parameters(self, f, options, position):
+        mods = f(self, options, position)
         for m in mods.macros_python:
             self.the_macros[m.name] = m
         for e in mods.environs:
@@ -198,7 +201,10 @@ class Parser:
                 buf.back(self.expand_item(buf, tok, out))
                 continue
             elif type(tok) is defs.MacroToken:
-                buf.back(self.expand_macro(buf, tok, False))
+                if tok.txt == '\\def':
+                    out += self.parse_def_macro(buf, tok.pos)
+                else:
+                    buf.back(self.expand_macro(buf, tok, False))
                 continue
             elif tok.txt == '$' or tok.txt == '\\(':
                 out += self.mathparser.expand_inline_math(buf, tok)
@@ -317,9 +323,11 @@ class Parser:
     def expand_arguments(self, buf, mac, start):
         arguments = []
         arguments_extr = []
+        delimiters = []
         pos = start
         for n, code in enumerate(mac.args):
             arg_extr = arg = []
+            delim = False
             tok = buf.skip_space()
             if tok:
                 pos = tok.pos
@@ -329,6 +337,7 @@ class Parser:
                     buf.next()
             elif code == 'O':
                 if tok and tok.txt == '[':
+                    delim = True
                     arg_extr = arg = self.arg_buffer(buf, pos, end=']').all()
                 else:
                     if n < len(mac.defaults):
@@ -338,12 +347,19 @@ class Parser:
                             t.pos = pos
                             t.pos_fix = True
             elif code == 'A':
-                arg_extr = arg = self.arg_buffer(buf, pos).all()
+                if tok and tok.txt == '}':
+                    # issue #135
+                    arg_extr = arg = [defs.VoidToken(pos)]
+                else:
+                    if tok and tok.txt == '{':
+                        delim = True
+                    arg_extr = arg = self.arg_buffer(buf, pos).all()
             else:
                 utils.fatal('illegal arg code ' + repr(code)
                                 + ' of ' + repr(mac.name))
             arguments.append(arg)
             arguments_extr.append(arg_extr)
+            delimiters.append(delim)
 
         if mac.extract:
             toks = ([defs.LanguageToken(start,
@@ -354,7 +370,7 @@ class Parser:
             self.extracted.append(self.expand_sequence(scanner.Buffer(toks)))
         out = [defs.ActionToken(start)]
         if callable(mac.repl):
-            return out + mac.repl(self, buf, mac, arguments, start)
+            return out + mac.repl(self, buf, mac, arguments, delimiters, start)
         return out + self.generate_replacements(arguments, mac.repl, start)
 
     def generate_replacements(self, arguments, repls, start):
@@ -449,7 +465,7 @@ class Parser:
             if env.add_pars:
                 out = [defs.ParagraphToken(tok.pos, '\n\n', pos_fix=True)]
             if env.end_func:
-                out += env.end_func(self, buf, env, [], tok.pos)
+                out += env.end_func(self, buf, env, [], [], tok.pos)
         return out, name == env_stop
 
     def get_environment_name(self, buf, tok):
@@ -673,3 +689,73 @@ class Parser:
             return (kv[0], self.get_text_expanded(kv[1]))
         return [f(kv) for kv in keyvals]
 
+    #   roughly approximated version of \def
+    #   - macro name must have form \xyz
+    #   - XXX:
+    #       - on expansion, absence of literal parameter tokens like '[' will
+    #         consume other tokens,
+    #       - these parameter tokens may mistakenly be enclosed in {} braces
+    #       - space in parameter text is not correctly treated
+    #
+    def parse_def_macro(self, buf, start):
+        buf.next()
+        tok = buf.skip_space()
+        if not tok:
+            return utils.latex_error('\\def: missing macro name', start,
+                                        self.latex, self.parms)
+        if type(tok) is not defs.MacroToken:
+            return utils.latex_error('\\def: illegal macro name "' + tok.txt
+                                        + '"', tok.pos, self.latex, self.parms)
+        name = tok.txt
+        args = []
+        while True:
+            buf.next()
+            tok = buf.skip_space()
+            if not tok:
+                return utils.latex_error('\\def: missing macro body', start,
+                                            self.latex, self.parms)
+            if tok.txt == '{':
+                break
+            args.append(tok)
+        repl = self.arg_buffer(buf, tok.pos).all()
+
+        n = 1
+        arg_pos_map = []
+        for k, t in enumerate(args, start=1):
+            if type(t) is defs.ArgumentToken:
+                if t.arg != n:
+                    return utils.latex_error('\\def: unexpected argument '
+                                                + repr(t.txt), t.pos,
+                                                self.latex, self.parms)
+                n += 1
+                arg_pos_map.append(k)
+
+        repl_mapped = []
+        for t in repl:
+            if type(t) is defs.ArgumentToken:
+                if t.arg < 1 or t.arg > len(arg_pos_map):
+                    return utils.latex_error(
+                            '\\def: illegal argument reference ' + repr(t.txt),
+                            t.pos, self.latex, self.parms)
+                t = copy.copy(t)
+                t.arg = arg_pos_map[t.arg - 1]
+            repl_mapped.append(t)
+        
+        self.the_macros[name] = defs.Macro(self.parms, name,
+                                        args='A'*len(args), repl=repl_mapped,
+                                        scanned=True)
+        return [defs.ActionToken(start)]
+
+    # generate an iterator that walks over tokens and appends {} levels
+    #
+    def iter_token_levels(self, tokens):
+        lev = 0
+        for tok in tokens:
+            if not tok:
+                continue
+            if tok.txt == '{':
+                lev += 1
+            elif tok.txt == '}':
+                lev -= 1
+            yield tok, lev
+
