@@ -27,12 +27,14 @@
 from yalafi import defs, tex2txt
 
 require_packages = []
-def init_module(parser, options):
+def init_module(parser, options, position):
     parms = parser.parms
-    def add(parser, buf, mac, args, pos):
-        name = parser.get_text_expanded(args[1])
+    def add(parser, buf, mac, args, delim, pos):
+        name = parser.get_text_expanded(args[1]).strip()
         if mac.name == '\\usepackage':
-            packages.append(name)
+            for p in name.split(','):
+                if p.strip():
+                    packages.append(p.strip())
         else:
             documentclass[0] = name
         return []
